@@ -336,10 +336,14 @@ art_render_gradient_linear_render_8 (ArtRenderCallback *self,
   assert ((stops[ix-1].offset <= offset_fraction + EPSILON) ||
 	  ((stops[ix].offset > (1.0 - EPSILON)) && (offset_fraction < EPSILON /* == 0.0*/)));
   assert (offset_fraction <= stops[ix].offset);
+  /* FIXME: These asserts may be broken, it is for now
+     safer to not use them.  Should be fixed!
+     See bug #121850
   assert ((offset_fraction != stops[ix-1].offset) ||
 	  (d_offset >= 0.0));
   assert ((offset_fraction != stops[ix].offset) ||
 	  (d_offset <= 0.0));
+  */
   
   while (width > 0)
     {
@@ -351,7 +355,7 @@ art_render_gradient_linear_render_8 (ArtRenderCallback *self,
 		     spread,
 		     offset,
 		     offset_fraction,
-		     (d_offset > 0.0),
+		     (d_offset > -EPSILON),
 		     ix,
 		     color1);
 
@@ -398,7 +402,7 @@ art_render_gradient_linear_render_8 (ArtRenderCallback *self,
 			 spread,
 			 offset,
 			 offset_fraction,
-			 (d_offset < 0.0),
+			 (d_offset < EPSILON),
 			 ix,
 			 color2);
 	  
@@ -418,7 +422,7 @@ art_render_gradient_linear_render_8 (ArtRenderCallback *self,
 	      if (ix == n_stops)
 		ix = 1;
 	      /* Note: offset_fraction can actually be one here on x86 machines that
-		 does calculations with extanded precision, but later rounds to 64bit.
+		 does calculations with extended precision, but later rounds to 64bit.
 		 This happens if the 80bit offset_fraction is larger than the
 		 largest 64bit double that is less than one.
 	      */
